@@ -41,7 +41,7 @@ class FTGUI_Top(Module):
 
     _code_filename = '' # name of file with user code
     code_maxlines = 200 # the number of lines to keep in the code text field
-    _code_state = 'off' # state of user code execution: off vs. loaded vs. running
+    _code_state = 'off' # state of user code execution: off vs. selected vs. running
     motorstickyness = 20 # don't allow very slow motor speeds (0,5,10,...; 0 disables stickyness)
 
     def __init__(self, top, enqueuing_func = None, scheduling_func=None):
@@ -288,13 +288,13 @@ class FTGUI_Top(Module):
         self.ButtonStop.configure(pady='0')
         self.ButtonStop.configure(text='Stop')
         self.ButtonStop.configure(state='disabled')
-        self.ButtonLoad = tk.Button(self.FrameCodeHeaderrow)
-        self.ButtonLoad.grid(column=3, row=1, sticky='nswe')
-        self.ButtonLoad.grid_configure(padx=3, pady=3)
-        self.configure_design(self.ButtonLoad, ['activebackground', 'activeforeground', 'background', 'disabledforeground', 'foreground', 'highlightbackground', 'highlightcolor'])
-        self.ButtonLoad.configure(command=self.on_button_code_load)
-        self.ButtonLoad.configure(pady='0')
-        self.ButtonLoad.configure(text='Load')
+        self.ButtonSelect = tk.Button(self.FrameCodeHeaderrow)
+        self.ButtonSelect.grid(column=3, row=1, sticky='nswe')
+        self.ButtonSelect.grid_configure(padx=3, pady=3)
+        self.configure_design(self.ButtonSelect, ['activebackground', 'activeforeground', 'background', 'disabledforeground', 'foreground', 'highlightbackground', 'highlightcolor'])
+        self.ButtonSelect.configure(command=self.on_button_code_select)
+        self.ButtonSelect.configure(pady='0')
+        self.ButtonSelect.configure(text='Select')
         self.LabelFilename = tk.Label(self.FrameCodeHeaderrow)
         self.LabelFilename.grid(column=4, row=1, sticky='nswe')
         self.LabelFilename.grid_configure(padx=3)
@@ -302,7 +302,7 @@ class FTGUI_Top(Module):
         self.LabelFilename.configure(activebackground='#f9f9f9')
         self.LabelFilename.configure(anchor='w')
         self.LabelFilename.configure(justify='left')
-        self.LabelFilename.configure(text='[no file with user code loaded]')
+        self.LabelFilename.configure(text='[no file with user code selected]')
         tooltip.ToolTip(self.LabelFilename, 'TkDefaultFont', 'This is the name of the file containing user code to be executed on demand', delay=0.5)
 
     @property
@@ -315,15 +315,15 @@ class FTGUI_Top(Module):
         '''Manipulate the state of user code execution in a consistent manner'''
         if self._code_state != value:
             if value == 'off':
-                self.ButtonLoad.configure(state='normal')
+                self.ButtonSelect.configure(state='normal')
                 self.ButtonStop.configure(state='disabled')
                 self.ButtonStart.configure(state='disabled')
-            elif value == 'loaded':
-                self.ButtonLoad.configure(state='normal')
+            elif value == 'selected':
+                self.ButtonSelect.configure(state='normal')
                 self.ButtonStop.configure(state='disabled')
                 self.ButtonStart.configure(state='normal')
             elif value == 'running':
-                self.ButtonLoad.configure(state='disabled')
+                self.ButtonSelect.configure(state='disabled')
                 self.ButtonStop.configure(state='normal')
                 self.ButtonStart.configure(state='disabled')
                 self.enqueue_event('on_start_code_requested', filename=self._code_filename)
@@ -367,17 +367,17 @@ class FTGUI_Top(Module):
         logger.debug('Button pressed [Stop]')
         if self._code_state == 'running': # if the code was running, we need to make sure it's stopped
             self.enqueue_event('on_stop_code_requested')
-        self.code_state = 'loaded'
+        self.code_state = 'selected'
         
-    def on_button_code_load(self):
-        '''React on pressing "load" button'''
-        logger.debug('Button pressed [Load]')
+    def on_button_code_select(self):
+        '''React on pressing "select" button'''
+        logger.debug('Button pressed [Select]')
         filename = tk.filedialog.askopenfilename()
         if len(filename) > 0:
             self._code_filename = filename
             logger.debug('Filename set to [{0}]'.format(self._code_filename))
             self.LabelFilename.configure(text=self._code_filename)
-            self.code_state = 'loaded'
+            self.code_state = 'selected'
 
     def on_motor_set_requested_tk(self, varname):
         '''Called when the setting for a given motor changes via Tk control'''
@@ -437,7 +437,7 @@ class FTGUI_Top(Module):
 
     def on_usercode_terminated(self, metadata):
         '''Called when the user's code was interrupted; called from external'''
-        self.code_state = 'loaded'
+        self.code_state = 'selected'
 
 
 if __name__ == '__main__':
